summaryrefslogtreecommitdiffstats
path: root/kalarm/lib/colourlist.h
diff options
context:
space:
mode:
Diffstat (limited to 'kalarm/lib/colourlist.h')
-rw-r--r--kalarm/lib/colourlist.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/kalarm/lib/colourlist.h b/kalarm/lib/colourlist.h
index 8ec2b2a9..7bee8d14 100644
--- a/kalarm/lib/colourlist.h
+++ b/kalarm/lib/colourlist.h
@@ -32,7 +32,7 @@
* The ColourList class holds a list of colours, sorted in RGB value order.
*
* It provides a sorted TQValueList of colours in RGB value order, with iterators
* and other access methods which return either QRgb or TQColor objects.
*
* @author David Jarvie <software@astrojar.org.uk>
*/
@@ -40,14 +40,14 @@ class ColourList
{
public:
typedef size_t size_type;
- typedef TQValueListConstIterator<QRgb> const_iterator;
+ typedef TQValueListConstIterator<TQRgb> const_iterator;
/** Constructs an empty list. */
ColourList() { }
/** Copy constructor. */
ColourList(const ColourList& l) : mList(l.mList) { }
/** Constructs a list whose values are preset to the colours in @p list. */
- ColourList(const TQValueList<QRgb>& list) : mList(list) { qHeapSort(mList); }
+ ColourList(const TQValueList<TQRgb>& list) : mList(list) { qHeapSort(mList); }
/** Constructs a list whose values are preset to the colours in the @p list.
* Terminate @p list by an invalid colour.
*/
@@ -55,7 +55,7 @@ class ColourList
/** Assignment operator. */
ColourList& operator=(const ColourList& l) { mList = l.mList; return *this; }
/** Sets the list to comprise the colours in @p list. */
- ColourList& operator=(const TQValueList<QRgb>& list) { mList = list; qHeapSort(mList); return *this; }
+ ColourList& operator=(const TQValueList<TQRgb>& list) { mList = list; qHeapSort(mList); return *this; }
/** Removes all values from the list. */
void clear() { mList.clear(); }
/** Adds the specified colour @p c to the list. */
@@ -82,16 +82,16 @@ class ColourList
const_iterator fromLast() const { return mList.fromLast(); }
/** Returns an iterator pointing to the colour at position @p i in the list. */
const_iterator at(size_type i) const { return mList.at(i); }
- /** Returns true if the list tqcontains the colour @p c. */
+ /** Returns true if the list contains the colour @p c. */
size_type tqcontains(const TQColor& c) const { return mList.tqcontains(c.rgb()); }
/** Returns an iterator pointing to the first occurrence of colour @p c in the list.
* Returns end() if colour @p c is not in the list.
*/
- const_iterator find(const TQColor& c) const { return mList.find(c.rgb()); }
+ const_iterator tqfind(const TQColor& c) const { return mList.tqfind(c.rgb()); }
/** Returns an iterator pointing to the first occurrence of colour @p c in the list, starting.
* from position @p it. Returns end() if colour @p c is not in the list.
*/
- const_iterator find(const_iterator it, const TQColor& c) const { return mList.find(it, c.rgb()); }
+ const_iterator tqfind(const_iterator it, const TQColor& c) const { return mList.tqfind(it, c.rgb()); }
/** Returns the index to the first occurrence of colour @p c in the list.
* Returns -1 if colour @p c is not in the list.
*/
@@ -104,7 +104,7 @@ class ColourList
TQColor operator[](size_type i) const { return TQColor(mList[i]); }
private:
void sort();
- TQValueList<QRgb> mList;
+ TQValueList<TQRgb> mList;
};
#endif // COLOURLIST_H
@@ -32,7 +32,7 @@
*
* It provides a sorted TQValueList of colours in RGB value order, with iterators
- * and other access methods which return either QRgb or TQColor objects.
+ * and other access methods which return either TQRgb or TQColor objects.
*
* @author David Jarvie <software@astrojar.org.uk>